.. _CfRadial: https://github.com/NCAR/CfRadial
.. _WMO CF extensions: https://community.wmo.int/activity-areas/wis/wmo-cf-extensions
.. _OPERA/ODIM_H5: https://www.eumetnet.eu/activities/observations-programme/current-activities/opera/
